@@ -1,8 +1,13 @@
 from typing import Literal
 import requests
 import json
+import os
 
-from . import StatusCode, ListingJsonNotFound, ItemIdNotFound
+from .enums import StatusCode
+
+from .exceptions import (
+    ListingJsonNotFound, ItemIdNotFound
+)
 
 
 class Item:
@@ -24,17 +29,21 @@ class Item:
 
 
 class LocalItem(Item):
-    def __init__(self, name: str, path="stalcraft/items.json", encoding="utf-8"):
+    def __init__(self, name: str, path: str="", encoding="utf-8"):
         """
         Search for Item ID by name in file
 
         name: Name of item (without quotes)
-        path: Path to the file, by default built-in stalcraft/items.json
+        path: Path to the file, by default built-in items.json
         encoding: File encoding, default utf-8
         """
 
         super().__init__(name)
 
+        if not path:
+            here = os.path.abspath(os.path.dirname(__file__))
+            path = f"{here}/data/items.json"
+
         self.path = path
         self.encoding = encoding
 
@@ -58,7 +67,7 @@ class LocalItem(Item):
 
 
 class WebItem(Item):
-    GITHUB_RAW = "http://raw.githubusercontent.com"
+    GITHUB_RAW = "raw.githubusercontent.com"
     REPOS = "EXBO-Studio/stalcraft-database"
     DEFAULT_BRANCH = "main"
 
@@ -84,11 +93,11 @@ class WebItem(Item):
 
     def _get_listing(self):
         response = requests.get(
-            f"{self.GITHUB_RAW}/{self.REPOS}/{self.DEFAULT_BRANCH}/{self.folder}/listing.json"
+            f"http://{self.GITHUB_RAW}/{self.REPOS}/{self.DEFAULT_BRANCH}/{self.folder}/listing.json"
         )
 
         if response.status_code != StatusCode.OK.value:
-            raise ListingJsonNotFound(f"Listing.json not found in '{self.REPOS}/main/{self.folder}'")
+            raise ListingJsonNotFound(f"Listing.json not found in '{self.REPOS}/{self.DEFAULT_BRANCH}/{self.folder}'")
 
         self.items_database = response.json()
 
